pub struct ModelGroup {
pub models: Vec<Models>,
/* private fields */
}Fields
models: Vec<Models>Implementations
Sourceimpl ModelGroup
impl ModelGroup
Sourcepub fn draw<'a>(
&'a self,
render_pass: &mut RenderPass<'a>,
write_to_all_outputs: bool,
pass_id: MeshRenderPass,
camera: &CameraData,
output5_type: Option<Output5Type>,
models_index: Option<usize>,
model_index: Option<usize>,
)
pub fn draw<'a>( &'a self, render_pass: &mut RenderPass<'a>, write_to_all_outputs: bool, pass_id: MeshRenderPass, camera: &CameraData, output5_type: Option<Output5Type>, models_index: Option<usize>, model_index: Option<usize>, )
Draw each mesh for each model.
Sourcepub fn draw_bounds<'a>(
&'a self,
render_pass: &mut RenderPass<'a>,
bind_group1: &'a BindGroup1,
culled_bind_group1: &'a BindGroup1,
camera: &CameraData,
)
pub fn draw_bounds<'a>( &'a self, render_pass: &mut RenderPass<'a>, bind_group1: &'a BindGroup1, culled_bind_group1: &'a BindGroup1, camera: &CameraData, )
Draw the bounding box for each model and group of models.
pub fn reset_morphs(&self, encoder: &mut CommandEncoder)
pub fn compute_morphs<'a>(&'a self, compute_pass: &mut ComputePass<'a>)
Sourcepub fn update_bone_transforms(
&self,
queue: &Queue,
animation: &Animation,
current_time_seconds: f32,
)
pub fn update_bone_transforms( &self, queue: &Queue, animation: &Animation, current_time_seconds: f32, )
Animate each of the bone transforms in the current skeleton.
Sourcepub fn update_morph_weights(
&self,
queue: &Queue,
animation: &Animation,
current_time_seconds: f32,
)
pub fn update_morph_weights( &self, queue: &Queue, animation: &Animation, current_time_seconds: f32, )
Update morph weights for all vertex buffers.